==> beaver-0.2.7.tar.gz: beaver-0.2.7/src/struct.h <==
/*
** Beaver's an Early AdVanced EditoR
** (C) 1999-2000 Marc Bevand, Damien Terrier and Emmanuel Turquin
**
** struct.h
**
** Author<s>:   Emmanuel Turquin (aka "Ender") <turqui_e@epita.fr>
** Latest update: Wed May  3 04:24:02 2000
** Description:   Beaver main structures, types definitions and macros
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __STRUCT_H__
#define __STRUCT_H__

/* Type: t_widget_info */

typedef struct
{
  GList *current_action;
  guint	SigConnectIns[2];
  guint SigConnectDel[2];
  guint	SigConnectChg[2];
  guint	SigConnectChgAft[2];
  gint Lg;
} t_widget_info;

/* Type: t_fprops */

typedef struct
{
  gchar *Name;
  gchar *BaseName;
  gchar *Type;
  t_widget_info WidgetInfo;
  gint ReadOnly;
  guint Changed[2];
  struct stat Stats;
  GtkWidget *Text;
} t_fprops;

/* Type: t_search_prefs */

typedef struct
{
  gchar *FileName;
  gchar *StringToSearch;
  gboolean BeginCursorPos;
  gboolean CaseSen;
  gboolean RegExp;
  gboolean RepAll;
  gboolean RepAllBuffers;
} t_search_prefs;

/* Type: t_search_tab */

typedef struct
{
  gint Line;
  gint Begin;
  gint End;
} t_search_results;

/* Type: t_settings */

typedef struct
{
  gint     recent_files;
  gboolean main_window_size_autosave;
  gint     main_window_width;
  gint     main_window_height;
  gboolean msgbar_display;
  gint     msgbar_interval;
  gboolean toggle_wordwrap;
  gboolean toolbar_display;
  gint     max_tab_label_length;
  gint     tab_position;
  gint     scrollbar_position;
  gint     complete_window_width;
  gint     complete_window_height;
  gint     bg[3];
  gint     fg[3];
  gint     selected_bg[3];
  gint     selected_fg[3];
  gboolean backup;
  gchar    *backup_ext;
  gint     autosave_delay;
  gchar    *directory;
  gchar    *font;
  gchar    *print_cmd;
  gchar    *wordfile;
  gboolean beep;
  gboolean syn_high;
  gint     syn_high_depth;
  gboolean auto_indent;
  gboolean auto_correct;
} t_settings;

/* Type: t_colors */

typedef struct
{
  gchar lg_descript[MAX_LANG][MAXLEN_LANG_DESCRIPTION];
  gint  colors[MAX_LANG][MAX_COL][3];
  gchar colors_descript[MAX_LANG][MAX_COL][MAXLEN_COL_DESCRIPTION];
  gboolean syhi_enable;
  gboolean auto_correct_enable;
  gboolean auto_indent_enable;
  gint syhi_depth;
} t_colors;

/* Type: t_conf */

typedef struct
{
  gchar **file_content;
  gint	section[2];
  gchar	*line;
}	t_conf;

/* Some usefull macros... */

#define FPROPS(Page, Elt) g_array_index (FileProperties, t_fprops, Page).Elt

#endif

==> beaver-0.3.1.tar.gz: beaver-0.3.1/src/struct.h <==
/*
** Beaver's an Early AdVanced EditoR
** (C) 1999-2000 Marc Bevand, Damien Terrier and Emmanuel Turquin
**
** struct.h
**
** Author<s>:   Emmanuel Turquin (aka "Ender") <turqui_e@epita.fr>
** Latest update: Wed May  3 04:24:02 2000
** Description:   Beaver main structures, types definitions and macros
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __STRUCT_H__
#define __STRUCT_H__

#include <time.h>

/*
** Here is different limits (imposed by UEdit), but they are not very
** well respected: there exists some wordfiles that overtake these
** limits, that's why I have implemented a syntax highlighting system
** that can be easily reconfigured (by changing the values defined)
**
** Especially, the values of MAXLEN_LANG_DESCRIPTION and
** MAXLEN_COL_DESCRIPTION (which was originally specified to be 8 in the
** reference documentation provided by UEdit) have been changed to 128 in
** order to support lots of wordfiles which descriptions were often more
** than 8 chars long
*/
#define MAX_LANG		10
#define MAXLEN_LANG_DESCRIPTION	128
#define MAX_COL			8
#define MAXLEN_COL_DESCRIPTION	128
/* MAXLEN_LINE_COMMENT must be a 1-digit number */
#define MAXLEN_LINE_COMMENT	3
#define MAXLEN_BLOCK_COMMENT	5

typedef enum {
  UNIX = 0,
  MAC,
  DOS
} FormatType;

/* Type: t_widget_info */

typedef struct
{
  
} t_widget_info;

/* Type: t_fprops */
/* This stores information related to each open file/textview */

typedef struct
{
  gchar *Name;	/* full filename */
  gchar *BaseName;
  gchar *Type;
  FormatType Format;
  t_widget_info WidgetInfo;
  gint ReadOnly;
  time_t LastSave;
  struct stat Stats;
  GtkWidget *Text;
  GtkTextBuffer *Buffer;
} t_fprops;

/* Type: t_search_prefs */

typedef struct
{
  gchar *FileName;
  const gchar *StringToSearch;
  gboolean BeginCursorPos;
  gboolean CaseSen;
  gboolean RegExp;
  gboolean RepAll;
  gboolean RepAllBuffers;
} t_search_prefs;

/* Type: t_search_tab */

typedef struct
{
  gint Line;
  gint Begin;
  gint End;
} t_search_results;

/* Type: t_settings */

typedef struct
{
  gint     recent_files;
  gboolean main_window_size_autosave;
  gint     main_window_width;
  gint     main_window_height;
  gboolean msgbar_display;
  gint     msgbar_interval;
  gboolean toggle_wordwrap;
  gboolean toolbar_display;
  gint     tab_position;
  gint     scrollbar_position;
  gint     complete_window_width;
  gint     complete_window_height;
  gint     bg[3];
  gint     fg[3];
  gint     selected_bg[3];
  gint     selected_fg[3];
  gboolean backup;
  gchar    *backup_ext;
  gint     autosave_delay;
  gchar    *directory;
  gchar    *font;
  gchar    *print_cmd;
  gboolean beep;
  gboolean auto_indent;
  gboolean auto_correct;
  gboolean show_line_numbers;
  gboolean show_margin;
  gint     tab_width;
} t_settings;

/* Type: t_colors */

typedef struct
{
  gchar lg_descript[MAX_LANG][MAXLEN_LANG_DESCRIPTION];
  gint  colors[MAX_LANG][MAX_COL][3];
  gchar colors_descript[MAX_LANG][MAX_COL][MAXLEN_COL_DESCRIPTION];
  gboolean syhi_enable;
  gboolean auto_correct_enable;
  gboolean auto_indent_enable;
  gint syhi_depth;
} t_colors;

/* Type: t_conf */

typedef struct
{
  gchar **file_content;
  gint	section[2];
  gchar	*line;
}	t_conf;

/* Some useful macros... */

#define FPROPS(Page, Elt) g_array_index (FileProperties, t_fprops, Page).Elt

#ifdef DEBUG_FCN
#define START_FCN \
	GTimer *fcn_timer = g_timer_new ();\
	g_print(__FILE__": %s(): Begin\n", __func__);
#else
#define START_FCN 
#endif

#ifdef DEBUG_FCN
#define END_FCN \
	g_print(__FILE__": %s(): End after %f seconds\n", __func__, \
		g_timer_elapsed (fcn_timer, NULL));\
	g_timer_destroy (fcn_timer);
#else
#define END_FCN 
#endif

#endif
